[Initng-svn] r2969 - initng/src

svn at initng.thinktux.net svn at initng.thinktux.net
Wed Feb 8 07:26:17 CET 2006


Author: thelich
Date: Wed Feb  8 07:26:15 2006
New Revision: 2969

Modified:
   initng/src/initng.h
   initng/src/initng_active_db.c
   initng/src/initng_active_db.h
   initng/src/initng_active_state.c
   initng/src/initng_active_state.h
   initng/src/initng_common.c
   initng/src/initng_control_command.c
   initng/src/initng_depend.c
   initng/src/initng_depend.h
   initng/src/initng_env_variable.c
   initng/src/initng_error.c
   initng/src/initng_execute.c
   initng/src/initng_fd.c
   initng/src/initng_fork.c
   initng/src/initng_global.c
   initng/src/initng_global.h
   initng/src/initng_handler.c
   initng/src/initng_kill_handler.c
   initng/src/initng_list.h
   initng/src/initng_load_module.c
   initng/src/initng_main.c
   initng/src/initng_open_read_close.c
   initng/src/initng_plist.c
   initng/src/initng_plist.h
   initng/src/initng_plugin_hook.c
   initng/src/initng_process_db.c
   initng/src/initng_service_cache.c
   initng/src/initng_service_cache.h
   initng/src/initng_service_data_types.c
   initng/src/initng_service_data_types.h
   initng/src/initng_service_types.h
   initng/src/initng_signal.c
   initng/src/initng_static_data_id.c
   initng/src/initng_static_process_types.c
   initng/src/initng_static_service_types.c
   initng/src/initng_static_states.c
   initng/src/initng_string_tools.c
   initng/src/initng_string_tools.h
   initng/src/initng_struct_data.c
   initng/src/main.c
Log:
major spellchecking

Modified: initng/src/initng.h
==============================================================================
--- initng/src/initng.h	(original)
+++ initng/src/initng.h	Wed Feb  8 07:26:15 2006
@@ -39,7 +39,7 @@
 
 #define INITNG_CREATOR "Jimmy Wennlund (jimmy.wennlund at gmail.com)"
 
-/* unset this in an pruduction environment */
+/* unset this in an production environment */
 /* this is set in config.h */
 /*#define DEBUG */
 
@@ -56,7 +56,7 @@
 /* after term is sent, wait these seconds before killing */
 #define SECONDS_BEFORE_KILL 2
 
-/* makes all services sleep this many microseconds before launcinh,
+/* makes all services sleep this many microseconds before launching,
  * this will get initng time to register service */
 #define ALL_USLEEP 1000
 

Modified: initng/src/initng_active_db.c
==============================================================================
--- initng/src/initng_active_db.c	(original)
+++ initng/src/initng_active_db.c	Wed Feb  8 07:26:15 2006
@@ -87,7 +87,7 @@
     /* did not find any */
     return NULL;
 
-    /* no need in pattern mathcing, because of unique names in cache (TeLich) */
+    /* no need in pattern matching, because of unique names in cache (TheLich) */
 
     /* walk the active db and compere */
     current = NULL;
@@ -250,18 +250,18 @@
         return (NULL);
     }
 
-    /* initize the data and process list */
+    /* initialize the data and process list */
     INIT_LIST_HEAD(&(new_active->data.list));
     INIT_LIST_HEAD(&(new_active->processes.list));
 
-    /* get the time, and copy that time to all time entrys */
+    /* get the time, and copy that time to all time entries */
     gettimeofday(&new_active->time_current_state, NULL);
     memcpy(&new_active->time_last_state, &new_active->time_current_state,
            sizeof(struct timeval));
     memcpy(&new_active->last_rought_time, &new_active->time_current_state,
            sizeof(struct timeval));
 	    
-    /* mark this service as stopped, becouse it is not yet starting, or running */
+    /* mark this service as stopped, because it is not yet starting, or running */
     new_active->current_state = &STOPPED;
     new_active->from_service = NULL;
 
@@ -280,7 +280,7 @@
 
     D_("(%s);\n", pf->name);
 
-    /* look if there are plugins, that is intrested to now, this is freeing */
+    /* look if there are plug-ins, that is interested to now, this is freeing */
     initng_common_mark_service(pf, &FREEING);
 
     while_processes_safe(current, safe, pf)
@@ -350,7 +350,7 @@
     active_db_h *current = NULL;
 
     assert(from);
-    /* !assert(to) to can be NULL, if we wana clear that entry */
+    /* !assert(to) to can be NULL, if we want clear that entry */
 
     /* walk the active_db */
     while_active_db(current)
@@ -371,7 +371,7 @@
     /* ok, go COUNT ALL */
     if (!current_state_to_count)
     {
-        /* ok, go thru all */
+        /* ok, go through all */
         while_active_db(current)
         {
             assert(current->name);
@@ -512,7 +512,7 @@
 
     assert(from_active);
 
-    /* look in active datas */
+    /* look in active data */
     if ((t = d_get_string_var(type, vn, &from_active->data.list)))
         return (t);
 
@@ -557,7 +557,7 @@
     if ((r = d_get_next_string_var(type, vn, &from_active->data.list, last)))
         return (r);
 
-    /* load service from disk, if nonexistant */
+    /* load service from disk, if nonexistent */
     if (!from_active->from_service)
         initng_common_get_service(from_active);
 
@@ -573,7 +573,7 @@
 {
     struct list_head *cur = NULL;
 
-    /* load service cache from disk, if nonexistant */
+    /* load service cache from disk, if nonexistent */
     if (!from_active->from_service)
         initng_common_get_service(from_active);
     if (!from_active->from_service)
@@ -590,7 +590,7 @@
     if (cur == &from_active->data.list)
         cur = from_active->from_service->data.list.prev;
 
-    /* if next is end of c_head, this is the totaly last one */
+    /* if next is end of c_head, this is the totally last one */
     if (cur == &from_active->from_service->data.list)
         return (NULL);
 
@@ -613,7 +613,7 @@
     if (d_is_var(type, vn, &from_active->data.list))
         return (TRUE);
 
-    /* load service from disk, if nonexistant */
+    /* load service from disk, if nonexistent */
     if (!from_active->from_service)
         initng_common_get_service(from_active);
 

Modified: initng/src/initng_active_db.h
==============================================================================
--- initng/src/initng_active_db.h	(original)
+++ initng/src/initng_active_db.h	Wed Feb  8 07:26:15 2006
@@ -55,7 +55,7 @@
     a_state_h *last_state;
     struct timeval time_last_state;     /* the time got last state */
 
-    /* Rought  state */
+    /* Rough  state */
     e_is last_rought_state;
     struct timeval last_rought_time;
 
@@ -74,7 +74,7 @@
     struct list_head list;
 };
 
-/* acllocate */
+/* allocate */
 active_db_h *initng_active_db_new(const char *name);
 
 /* searching */
@@ -84,7 +84,7 @@
 active_db_h *initng_active_db_find_by_pid(pid_t pid);
 active_db_h *initng_active_db_find_by_service_h(service_cache_h * service);
 
-/* mangeling */
+/* mangling */
 void initng_active_db_change_service_h(service_cache_h * from,
                                        service_cache_h * to);
 void initng_active_db_compensate_time(time_t skew);

Modified: initng/src/initng_active_state.c
==============================================================================
--- initng/src/initng_active_state.c	(original)
+++ initng/src/initng_active_state.c	Wed Feb  8 07:26:15 2006
@@ -31,7 +31,7 @@
 {
     assert(state);
 
-    /* look for duplets */
+    /* look for duplicates */
     if (initng_active_state_find(state->state_name) != NULL)
     {
         F_("There exists a state with this state_name (%s) already, please check this!\n", state->state_name);
@@ -42,7 +42,7 @@
     /* add this state, to the big list of states */
     list_add(&(state->list), &(g.states.list));
 
-    /* initziate the list of tests for this state */
+    /* initialize the list of tests for this state */
     INIT_LIST_HEAD(&state->test.list);
 
     /* return happily */

Modified: initng/src/initng_active_state.h
==============================================================================
--- initng/src/initng_active_state.h	(original)
+++ initng/src/initng_active_state.h	Wed Feb  8 07:26:15 2006
@@ -41,7 +41,7 @@
 typedef struct
 {
     /*
-     * Function that will be called, before a serice is set this state.
+     * Function that will be called, before a service is set this state.
      * If return is FALSE, it wont allow this change.
      */
     int (*state_test) (active_db_h * service, a_state_h * state);
@@ -65,7 +65,7 @@
     /* the name of the state in a string, will be printed */
     const char *state_name;
 
-    /* If this state is set for a service, is it roghly: */
+    /* If this state is set for a service, is it roughly: */
     e_is is;
 
     /*
@@ -75,7 +75,7 @@
 
 
     /*
-     * The tests that shud be run, before a service can get this state.
+     * The tests that should be run, before a service can get this state.
      */
     a_state_hook test;
 

Modified: initng/src/initng_common.c
==============================================================================
--- initng/src/initng_common.c	(original)
+++ initng/src/initng_common.c	Wed Feb  8 07:26:15 2006
@@ -48,7 +48,7 @@
 #include "initng_depend.h"
 
 /*
- * this fuction walks thru the g.Argv, if it founds service name,
+ * this function walks through the g.Argv, if it founds service name,
  * with an starting -service, this function will return FALSE, and
  * the service wont be able to load, means that is it blacklisted.
  * return TRUE if service is okay to load.
@@ -115,7 +115,7 @@
         return (NULL);
     }
 
-    /* Mark this service as state LOADING, plugins may hook here */
+    /* Mark this service as state LOADING, plug-ins may hook here */
     if (!initng_common_mark_service(a_new, &LOADING))
     {
 	W_("Failed to mark service LOADING.\n");
@@ -139,13 +139,13 @@
     /* circular dependencies are BAD, so check this one before adding it to the db */
     /* dep_on_deep will not crash as long as the offending service is not loaded into the db */
 
-    /* dep_on_deep will loop over the activ_db, but as the a_new service is not added to 
+    /* dep_on_deep will loop over the active_db, but as the a_new service is not added to 
      * the service db up to now, this will not cause an endless loop, cause it will not
      * loop over a_new */
 
-    /* dep_on_deep() requires dep_on(), which uses sring based comparison, and will completely
-     * ignor the active_db. This is at least true for the dep_on() check thats implementet by
-     * the depend plugin(). In future plugins, do NOT implement dep_on() code that will require
+    /* dep_on_deep() requires dep_on(), which uses string based comparison, and will completely
+     * ignore the active_db. This is at least true for the dep_on() check that's implemented by
+     * the depend plugin(). In future plug-ins, do NOT implement dep_on() code that will require
      * any of the services being added to the active_db */
     if (g.no_circular == 0)
     {
@@ -165,7 +165,7 @@
     if (initng_active_db_add(a_new) == TRUE)
         return (a_new);
 
-    /* fail by defaukt */
+    /* fail by default */
     F_("active_db_add() FAILED!\n");
     if (a_new)
         initng_active_db_free(a_new);
@@ -196,7 +196,7 @@
         return (FALSE);
 
 
-    /* check the cacha database for an exact match */
+    /* check the cache database for an exact match */
     if ((service->from_service =
          initng_service_cache_find_by_exact_name(service->name)))
     {
@@ -218,7 +218,7 @@
     D_(" get_service(%s): got service from initng dynamic parsers.\n",
        service->name);
 
-    /* will continue here only, if initng_modules_parse did suceed */
+    /* will continue here only, if initng_modules_parse did succeed */
 
     /*
      * if service->name is "samba", and service->from_service->name is "daemon/samba" 
@@ -258,7 +258,7 @@
 
 /*
  * when a service fails to start, this function
- * walks thru all its dependencys, and mark it "dependency failed to start"
+ * walks through all its dependencies, and mark it "dependency failed to start"
  */
 static void dep_failed_to_start(active_db_h * service)
 {
@@ -279,7 +279,7 @@
 #ifdef DEP_FAILED_TO_STOP
 /*
  * when a service fails to stop, this function
- * walks thru all its dependencys, and mark it "dependency failed to stop"
+ * walks through all its dependencies, and mark it "dependency failed to stop"
  */
 static void dep_failed_to_stop(active_db_h * service)
 {
@@ -306,7 +306,7 @@
     if (g.sys_state != STATE_STARTING)
         return;
 
-    /* check actives, if any hase one of these status, system cant be set to STATE_UP */
+    /* check actives, if any has one of these status, system cant be set to STATE_UP */
     while_active_db(current)
     {
         if (IS_STARTING(current))
@@ -323,7 +323,7 @@
     s_call *current, *safe = NULL;
     service_cache_h *service = NULL;
 
-    /* first check service chache */
+    /* first check service cache */
     service = initng_service_cache_find_by_name(name);
     if (service)
         return (service);
@@ -343,7 +343,7 @@
     if (!service)
         return (NULL);
 
-    /* Maby there is pluins that will parse extra data */
+    /* May be there is plug-ins that will parse extra data */
     current = NULL;
     safe = NULL;
     while_list_safe(current, &g.ADDITIONAL_PARSE, safe)
@@ -362,7 +362,7 @@
  * Use this function to change the status of an service, this
  * function might refuse to change to that state, and if that
  * it will return FALSE, please always check the return value
- * when calling this funcion.
+ * when calling this function.
  */
 int initng_common_mark_service(active_db_h * service, a_state_h * state)
 {
@@ -394,7 +394,7 @@
         {
             int i;
 
-            /* check the cace list, this check may allredy succeded */
+            /* check the cache list, this check may already succeeded */
             for (i = 0; i < MAX_SUCCEEDED && service->succeeded[i]; i++)
             {
                 if (service->succeeded[i] == hook->state_test)
@@ -422,12 +422,12 @@
     /* Set INTERRUPT */
     initng_global_set_interrupt();
 
-    /* Fill last entrys */
+    /* Fill last entries */
     service->last_state = service->current_state;
     memcpy(&service->time_last_state, &service->time_current_state,
            sizeof(struct timeval));
 
-    /* update rught last to */
+    /* update rough last to */
     if (service->last_rought_state != service->current_state->is)
     {
 	service->last_rought_state=service->current_state->is;

Modified: initng/src/initng_control_command.c
==============================================================================
--- initng/src/initng_control_command.c	(original)
+++ initng/src/initng_control_command.c	Wed Feb  8 07:26:15 2006
@@ -35,7 +35,7 @@
 
     assert(cmd);
 
-    /* look for duplets */
+    /* look for duplicates */
     while_command_db(current)
     {
         if (current == cmd || current->command_id == cmd->command_id)
@@ -123,7 +123,7 @@
     }
     if(arg && cmd->opt_type == NO_OPT)
     {
-	F_("Command %c dont uses any options!\n", cid);
+	F_("Command %c don't uses any options!\n", cid);
 	return(FALSE);
     }
 

Modified: initng/src/initng_depend.c
==============================================================================
--- initng/src/initng_depend.c	(original)
+++ initng/src/initng_depend.c	Wed Feb  8 07:26:15 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
  * Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
  *
  * This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@
 
 /*
  * initng_depend:
- *  Will check with all plugins and return TRUE
+ *  Will check with all plug-ins and return TRUE
  *  if service depends on check.
  */
 int initng_depend(active_db_h * service, active_db_h * check)
@@ -70,12 +70,12 @@
 }
 
 /*
- * A deeper deepfind.
+ * A deeper deep-find.
  * Logic, we wanna make sure that depend check in a deeper level.
  * if daemon/smbd -> daemon/samba -> system/checkroot -> system/initial.
  * So should initng_depend_deep(daemon/smbd, system/initial) == TRUE
  *
- * Sumary, does service depends on check?
+ * Summary, does service depends on check?
  */
 static int initng_depend_deep2(active_db_h * service, active_db_h * check,
                                   int *stack);
@@ -96,16 +96,16 @@
         return (FALSE);
 
     /* if service depends on check, it also dep_on_deep's on check */
-    /* this serves as an exit from the recusrion */
+    /* this serves as an exit from the recursion */
     if (initng_depend(service, check))
         return (TRUE);
 
-    /* in case there is a circular dependency, break after 10 levels of recusrion */
+    /* in case there is a circular dependency, break after 10 levels of recursion */
     (*stack)++;
     if (*stack > 10)
         return (FALSE);
 
-    /* loop over all services, if service depends on current, recursivly check if
+    /* loop over all services, if service depends on current, recursively check if
      * current may depend (deep) on check */
     while_active_db(current)
     {
@@ -157,7 +157,7 @@
 }
 
 /*
- * This will check with plugins if dependecys for start this is met.
+ * This will check with plug-ins if dependencies for start this is met.
  * If this returns FALSE deps are not met yet, try later.
  * If this returns FAIL deps wont ever be met, so stop trying.
  */
@@ -176,7 +176,7 @@
 }
 
 /*
- * This will check with plugins if depedencys for stop is met.
+ * This will check with plug-ins if dependencies for stop is met.
  * If this returns FALSE deps for stopping are not met, try again later.
  * If this returns FAIL stop deps, wont EVER be met, stop trying.
  */
@@ -196,7 +196,7 @@
 
 /*
  * Start all deps, required or needed.
- * If a requred deps failed to start, this will return FALSE
+ * If a required deps failed to start, this will return FALSE
  */
 int initng_depend_start_deps(active_db_h * service)
 {
@@ -207,7 +207,7 @@
 
     while ((tmp = initng_active_db_get_next_string(&REQUIRE, service, tmp)))
     {
-        /* look if it exits allredy */
+        /* look if it exits already */
         if (initng_active_db_find_by_name(tmp))
         {
             D_("No need to LOAD %s, it is already loaded!\n", tmp);
@@ -227,7 +227,7 @@
 
     while ((tmp = initng_active_db_get_next_string(&NEED, service, tmp)))
     {
-        /* look if it exits allredy */
+        /* look if it exits already */
         if (initng_active_db_find_by_name(tmp))
         {
             D_("No need to LOAD %s, it is already loaded!\n", tmp);

Modified: initng/src/initng_depend.h
==============================================================================
--- initng/src/initng_depend.h	(original)
+++ initng/src/initng_depend.h	Wed Feb  8 07:26:15 2006
@@ -1,4 +1,4 @@
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
  * Copyright (C) 2005 neuron <neuron at hollowtube.mine.nu>
  *
  * This program is free software; you can redistribute it and/or

Modified: initng/src/initng_env_variable.c
==============================================================================
--- initng/src/initng_env_variable.c	(original)
+++ initng/src/initng_env_variable.c	Wed Feb  8 07:26:15 2006
@@ -83,7 +83,7 @@
      * FIRST, try to figure out how big array we want to create.
      */
 
-    /*  At least 11 allocatons below, and place for plugin added to (about 100) */
+    /*  At least 11 allocations below, and place for plugin added to (about 100) */
     allocate = 114;
 
     /* count existing env's */
@@ -108,7 +108,7 @@
     }
 #endif
 
-    /* add all static defined abow in initng_environ */
+    /* add all static defined above in initng_environ */
     for (nr = 0; initng_environ[nr]; nr++)
     {
         env[nr] = i_strdup(initng_environ[nr]);
@@ -201,10 +201,10 @@
                 strcat(var, "=");
                 strcat(var, fixed);
 
-                /* free the fixed onces */
+                /* free the fixed ones */
                 free(fixed);
 
-                /* check for dupplets */
+                /* check for duplicates */
                 for (i = 0; i < nr; i++)
                 {
                     if (is_same_env_var(env[i], var))
@@ -285,8 +285,8 @@
     if (!from)
         return (NULL);
 
-    /* alocate that mutch memory that we think we need */
-    /* TODO, add checkings that this value is never overridden */
+    /* allocate that much memory that we think we need */
+    /* TODO, add checks that this value is never overridden */
     to = (char *) i_calloc((strlen(from) + 150), sizeof(char));
     if (!to)
         return (NULL);
@@ -298,7 +298,7 @@
         int len = 0;
 
         /*
-         * if its not containing the magical char loop, youst copy the
+         * if its not containing the magical char loop, just copy the
          * char and continue the main loop.
          */
         if (from[0] != '$')
@@ -317,7 +317,7 @@
             continue;
 
         /*
-         * Calculate lenght of variable ${VARIABLE}.
+         * Calculate length of variable ${VARIABLE}.
          */
         if (from[0] == '{')                 /* if this is a ${VARIABLE} */
         {
@@ -427,10 +427,10 @@
             /* if we got an entry, and if the entry exits in this service */
             if (entry && initng_active_db_is(entry, s))
             {
-                /* Handle diffrently with diffrent types */
+                /* Handle differently with different types */
                 switch (entry->opt_type)
                 {
-                        /* if it is a string, youst strcpy in it */
+                        /* if it is a string, just strcpy in it */
                     case STRING:
                         {
                             strcpy(set,

Modified: initng/src/initng_error.c
==============================================================================
--- initng/src/initng_error.c	(original)
+++ initng/src/initng_error.c	Wed Feb  8 07:26:15 2006
@@ -88,7 +88,7 @@
     if (lock_error_printing == 1)
         return (0);
 
-    /* put the lock, to avoid a cirular bug */
+    /* put the lock, to avoid a circular bug */
     lock_error_printing = 1;
 
     /* start the variable list */
@@ -107,7 +107,7 @@
         va_end(pass);
     }
 
-    /* Print on failsafe if no hook is to lissen. */
+    /* Print on failsafe if no hook is to listen. */
     if (delivered != TRUE)
     {
         va_list pass;
@@ -315,7 +315,7 @@
         fprintf(stderr, " NON_INIT: ");
     }
 
-    /* Don't fech time, until we know we wanna print on screen */
+    /* Don't fetch time, until we know we wanna print on screen */
     t = time(0);
     ts = localtime(&t);
 

Modified: initng/src/initng_execute.c
==============================================================================
--- initng/src/initng_execute.c	(original)
+++ initng/src/initng_execute.c	Wed Feb  8 07:26:15 2006
@@ -59,7 +59,7 @@
     process = initng_process_db_get(type, service);
     if (process != NULL)
     {
-        F_("There exists an \"%s\" process in \"%s\" allready.\n",
+        F_("There exists an \"%s\" process in \"%s\" already.\n",
            process->pt->name, service->name);
         /*assert(NULL); */
         return (FALSE);
@@ -82,7 +82,7 @@
         /* call the start */
         ret = (*current->c.launch) (service, process);
 
-        /* if lauch succeded */
+        /* if launch succeeded */
         if (ret >= TRUE)
             return (TRUE);
 

Modified: initng/src/initng_fd.c
==============================================================================
--- initng/src/initng_fork.c	(original)
+++ initng/src/initng_fork.c	Wed Feb  8 07:26:15 2006
@@ -104,12 +104,12 @@
         }
 
         /*
-         * set up filedescriptors, for local fork,
-         * a fork in initng, should now rescive any input, but stdout & stderr, should be sent
+         * set up file descriptors, for local fork,
+         * a fork in initng, should now receive any input, but stdout & stderr, should be sent
          * to process->out_pipe[], that is set up by pipe() #man 2 pipe
          * [0] for reading, and [1] for writing, as the pipe is for sending output
          * FROM the fork, to initng for handle, the input part should be closed here,
-         * the other are maped to STDOUT and STDERR.
+         * the other are mapped to STDOUT and STDERR.
          */
 
         /* close stdin/stdout/stderr */
@@ -132,7 +132,7 @@
 
 
 
-        /* There might be plugins that will work here */
+        /* There might be plug-ins that will work here */
         while_list(current, &g.A_FORK)
         {
             if (((*current->c.af_launcher) (service, process)) == FALSE)
@@ -143,7 +143,7 @@
             }
         }
 
-        /* close all open fds, exept STDIN, STDOUT, STDERR (0, 1, 2) */
+        /* close all open fds, except STDIN, STDOUT, STDERR (0, 1, 2) */
         {
             int i;
 
@@ -163,7 +163,7 @@
     else
     {
 
-        /* close the resiveing end on pipe, on parent */
+        /* close the receiving end on pipe, on parent */
         close(process->out_pipe[1]);
         process->out_pipe[1] = -1;
 

Modified: initng/src/initng_global.c
==============================================================================
--- initng/src/initng_global.c	(original)
+++ initng/src/initng_global.c	Wed Feb  8 07:26:15 2006
@@ -32,7 +32,7 @@
 #include "initng_handler.h"
 #include "initng_static_service_types.h"
 
-/* HERE IS THE GLOBAL DEFINED STRUCT, WE OFTHEN RELATE TO */
+/* HERE IS THE GLOBAL DEFINED STRUCT, WE OFTEN RELATE TO */
 s_global g;
 static void initng_global_parse_argv(char **argv);
 
@@ -77,7 +77,7 @@
     D_("Maximum length for our process name is %d\n", g.maxproclen);
 
     /*
-     * initziate all databases, next and prev have to point to own struct
+     * initialize all databases, next and prev have to point to own struct
      */
     INIT_LIST_HEAD(&g.active_database.list);
     INIT_LIST_HEAD(&g.service_cache.list);
@@ -113,7 +113,7 @@
     INIT_LIST_HEAD(&g.UP_MET.list);
 
     /*
-     * default global variables - clearesed by memset abowe
+     * default global variables - cleared by memset above
      * g.interrupt = FALSE;
      * g.sys_state = STATE_NULL;
      * g.runlevel = NULL;
@@ -131,7 +131,7 @@
     /* Add static stypes */
     initng_service_add_static_stypes();
 
-    /* CLEARED by memset abow 
+    /* CLEARED by memset above 
        #ifdef DEBUG
        g.verbose = 0;
        {
@@ -221,7 +221,7 @@
     initng_service_data_types_free_all();   /* clean option_db */
     initng_command_free_all();              /* clean command_db */
 
-    /* free runlevelname string */
+    /* free runlevel name string */
     if (g.runlevel)
         free(g.runlevel);
 
@@ -229,7 +229,7 @@
     if (g.dev_console)
         free(g.dev_console);
 
-    /* free ur copy of argv, and argc */
+    /* free our copy of argv, and argc */
     for (i = 0; i < g.Argc; i++)
     {
         free(g.Argv[i]);

Modified: initng/src/initng_global.h
==============================================================================
--- initng/src/initng_global.h	(original)
+++ initng/src/initng_global.h	Wed Feb  8 07:26:15 2006
@@ -59,26 +59,26 @@
     stype_h stypes;
 
     /* all hooks to hook at */
-    s_call ASTATUS_CHANGE;	/* Calles as sonn as the ASTATUS changes */
-    s_call PARSERS;		/* Called when a service neds its data */
+    s_call ASTATUS_CHANGE;	/* Calls as soon as the ASTATUS changes */
+    s_call PARSERS;		/* Called when a service needs its data */
     s_call ADDITIONAL_PARSE;	/* Called after a service been parsed, and extra parsing may exist */
     s_call SWATCHERS;		/* Called when system state changes */
-    s_call FDWATCHERS;		/* Called when initng open filedescriptors recive data */
-    s_call PIPEWATCHERS;	/* Called when a service has some output, that initng rescived */
-    s_call ALARM;		/* Called when the sceduler is set, and go of */
+    s_call FDWATCHERS;		/* Called when initng open file descriptors receive data */
+    s_call PIPEWATCHERS;	/* Called when a service has some output, that initng received */
+    s_call ALARM;		/* Called when the scheduler is set, and go of */
     s_call HUP;			/* Called when sighup signal was received */
     s_call MAIN;		/* Called every main loop */
     s_call A_FORK;		/* Called after a process forks to start */
     s_call HANDLE_KILLED;	/* Called when a process dies */
     s_call COMPENSATE_TIME;	/* Called when initng detects a system time change */
-    s_call ERR_MSG;		/* Called when an error message is sent, so all output plugins can show it */
+    s_call ERR_MSG;		/* Called when an error message is sent, so all output plug-ins can show it */
     s_call LAUNCH;		/* Called when a process are getting launched */
-    s_call DUMP_STATE;		/* Tells plugins to dump all their data to disk, becouse initng will be reloaded */
-    s_call RELOAD_STATE;	/* Tells plugins to reload allk their data from disk */
-    s_call DEP_ON;		/* Called when a function trys to find out a service dependency */
+    s_call DUMP_STATE;		/* Tells plug-ins to dump all their data to disk, because initng will be reloaded */
+    s_call RELOAD_STATE;	/* Tells plug-ins to reload all their data from disk */
+    s_call DEP_ON;		/* Called when a function tries to find out a service dependency */
 
     /* new ones */
-    s_call IS_CHANGE;		/* Called when the rought state of a service changes */
+    s_call IS_CHANGE;		/* Called when the rough state of a service changes */
     s_call START_DEP_MET;	/* Called and all this hooks have to return TRUE for launch to start */
     s_call STOP_DEP_MET;	/* Called and all this hooks have to return TRUE for the service to stop */
     s_call UP_MET;	/* Called when a service is trying to set the RUNNING state, is a up test */
@@ -126,7 +126,7 @@
 /* this is defined in initng_global.c */
 extern s_global g;
 
-/* functions for initziate and free s_global g */
+/* functions for initialize and free s_global g */
 void initng_global_new(int argc, char *argv[], char *env[]);
 void initng_global_free(void);
 

Modified: initng/src/initng_handler.c
==============================================================================
--- initng/src/initng_kill_handler.c	(original)
+++ initng/src/initng_kill_handler.c	Wed Feb  8 07:26:15 2006
@@ -82,7 +82,7 @@
 
     while_processes_safe(process, safe, service)
     {
-        /* make sure thats the right process */
+        /* make sure it's the right process */
         D_("There exists a process type %s in db with pid %i\n",
            process->pt->name, process->pid);
         if (process->pid != kpid)
@@ -120,6 +120,6 @@
         return;
     }
 
-    F_("handle_killed_by_pid(%i): traced killed pid to a service but can't find servicetype!\n", kpid);
+    F_("handle_killed_by_pid(%i): traced killed pid to a service but can't find service type!\n", kpid);
     return;
 }

Modified: initng/src/initng_list.h
==============================================================================
--- initng/src/initng_list.h	(original)
+++ initng/src/initng_list.h	Wed Feb  8 07:26:15 2006
@@ -57,7 +57,7 @@
  */
 static inline void list_add(struct list_head *new, struct list_head *head)
 {
-    /* make sure its not alreddy added */
+    /* make sure its not already added */
     if (new->next || new->prev)
         return;
     __list_add(new, head, head->next);
@@ -74,7 +74,7 @@
 static inline void list_add_tail(struct list_head *new,
                                  struct list_head *head)
 {
-    /* make sure its not alreddy added */
+    /* make sure its not already added */
     if (new->next || new->prev)
         return;
     __list_add(new, head->prev, head);

Modified: initng/src/initng_load_module.c
==============================================================================
--- initng/src/initng_load_module.c	(original)
+++ initng/src/initng_load_module.c	Wed Feb  8 07:26:15 2006
@@ -66,7 +66,7 @@
  *
  * Modules that result in circular dependencies can never be loaded.
  *
- * Several things are missing from the depencency setup:
+ * Several things are missing from the dependency setup:
  *
  * - Some notion of "services". A module can depend on only specific
  *   module, say "cpout", not "any module that provides output".
@@ -184,7 +184,7 @@
 
     D_("Success opening module \"%s\"\n", module_name);
 
-    /* get intialisation function */
+    /* get initialization function */
     dlerror();                              /* clear any existing error */
     m->module_init = dlsym(m->module_dlhandle, "module_init");
     if (m->module_init == NULL)
@@ -463,10 +463,10 @@
 
     free(module_path);
 
-    /* load the entries on our todo list */
+    /* load the entries on our TODO list */
     while_module_db_safe(current, safe)
     {
-        /* allredy initziated */
+        /* already initialized */
         if (current->initziated == TRUE)
             continue;
 
@@ -481,7 +481,7 @@
         D_("for module \"%s\" return: %i\n", current->module_name,
            current->initziated);
 
-        /* check if it was initziated correctly */
+        /* check if it was initialized correctly */
         if (current->initziated != TRUE)
         {
             F_("Module %s did not load correctly (module_init() returned %i)\n", current->module_name, current->initziated);

Modified: initng/src/initng_main.c
==============================================================================
--- initng/src/initng_main.c	(original)
+++ initng/src/initng_main.c	Wed Feb  8 07:26:15 2006
@@ -62,7 +62,7 @@
     /* If the last process has died, quit initng */
     while_active_db(current)
     {
-        /* Dont check with failed services */
+        /* Don't check with failed services */
         if (IS_FAILED(current))
             continue;
 	
@@ -81,7 +81,7 @@
     return (TRUE);
 }
 
-/* this is called when there is no processses left */
+/* this is called when there is no processes left */
 void initng_main_when_out(void)
 {
     if (g.i_am_init && getpid() != 1)
@@ -94,7 +94,7 @@
     /* always good to do */
     sync();
 
-    /* none of these calls shud return, so the su_login on the end will be a fallback */
+    /* none of these calls should return, so the su_login on the end will be a fallback */
     switch (g.when_out)
     {
         case THEN_QUIT:
@@ -149,7 +149,7 @@
     {
 	fclose(test);
 	unlink("/initng_write_testfile");
-	F_("/ IS NOT REMOUNTED READONLY, WONT REBOOT/HALT BECOUSE THE FILESYSTEM CAN BREAK!\n");
+	F_("/ IS NOT REMOUNTED READ-ONLY, WONT REBOOT/HALT BECAUSE THE FILE SYSTEM CAN BREAK!\n");
 	return;
     }
     	
@@ -157,7 +157,7 @@
     if (t==THEN_REBOOT) reboot(RB_AUTOBOOT);
     if (t==THEN_HALT) reboot(RB_POWER_OFF);
 	    
-    /* iddle forewer */
+    /* idle forever */
     while(1) sleep(1);
 
 
@@ -322,7 +322,7 @@
     execve("/sbin/initng", argv, environ);
 }
 
-/* this function sets g.sys_state, and call plugins that listen on its change */
+/* this function sets g.sys_state, and call plug-ins that listen on its change */
 void initng_main_set_sys_state(h_sys_state state)
 {
     /* don't set a state that is */
@@ -355,13 +355,13 @@
     /* Then, unload all modules */
     initng_unload_module_unload_all();
     
-    /* And exit with returncode */
+    /* And exit with return code */
     exit(i);
 }
 
 /*
  * This is called on segfault,
- * DONT call any other funtion in initng from here, not even P_, F_, W_!
+ * DON'T call any other function in initng from here, not even P_, F_, W_!
  */
 void initng_main_segfault(void)
 {
@@ -370,7 +370,7 @@
     /* if this is not init */
     if (!g.i_am_init)
     {
-        /* youst quit */
+        /* just quit */
         _exit(99);
     }
 

Modified: initng/src/initng_open_read_close.c
==============================================================================
--- initng/src/initng_open_read_close.c	(original)
+++ initng/src/initng_open_read_close.c	Wed Feb  8 07:26:15 2006
@@ -39,7 +39,7 @@
 
 int open_read_close(const char *filename, char **buffer)
 {
-    int conf_file;              /* File descriptor for configfile */
+    int conf_file;              /* File descriptor for config file */
     struct stat stat_buf;
     int res;                    /* Result of read */
 
@@ -50,7 +50,7 @@
 
     /* */
 
-    conf_file = open(filename, O_RDONLY);   /* Open configfile. */
+    conf_file = open(filename, O_RDONLY);   /* Open config file. */
 
     if (conf_file == -1)
     {
@@ -112,7 +112,7 @@
     return (TRUE);
 }
 
-/* Avoid using goto sending a pointer to conf_file */
+/* Avoid using go to sending a pointer to conf_file */
 static void bailout(int *p_conf_file, char **buffer)
 {
     /* if conf_file != -1 it is open */

Modified: initng/src/initng_plist.c
==============================================================================
--- initng/src/initng_plist.c	(original)
+++ initng/src/initng_plist.c	Wed Feb  8 07:26:15 2006
@@ -51,7 +51,7 @@
     plist->allocated += plist->alloc_heap;
     new_plist = realloc(plist->list, (sizeof(void *) * plist->allocated));
 
-    /* make sure it succeded */
+    /* make sure it succeeded */
     if (!new_plist)
         return (FALSE);
 

Modified: initng/src/initng_plist.h
==============================================================================
--- initng/src/initng_plist.h	(original)
+++ initng/src/initng_plist.h	Wed Feb  8 07:26:15 2006
@@ -48,13 +48,13 @@
 int plist_del(void *pointer, plist_h * plist);
 void plist_clear(plist_h * plist);
 
-/* initziates an itterator with a plist */
+/* initialize an iterator with a plist */
 #define PIT_INIT(pl, pit) { (pit)->plist = (pl); (pit)->count = 0; }
 
-/* get the value from an itterator */
+/* get the value from an iterator */
 #define V(pit) (pit)->plist->list[(pit)->count]
 
-/* walks the itterator */
+/* walks the iterator */
 #define FOR_LIST(pit) for((pit)->count=0; (pit)->plist->list && (pit)->count < (pit)->plist->next_to_set; (pit)->count++)
 #define FOR_LIST_REW(pit) for((pit)->count=(pit)->plist->next_to_set-1; (pit)->plist->list && (pit)->count >= 0 ; (pit)->count--)
 #endif

Modified: initng/src/initng_plugin_hook.c
==============================================================================
--- initng/src/initng_plugin_hook.c	(original)
+++ initng/src/initng_plugin_hook.c	Wed Feb  8 07:26:15 2006
@@ -81,7 +81,7 @@
     if (list_empty(&t->list))
     {
         list_add(&new_call->list, &t->list);
-        D_("Hook added to list sucessfully, as first.\n");
+        D_("Hook added to list successfully, as first.\n");
         return (TRUE);
     }
 

Modified: initng/src/initng_process_db.c
==============================================================================
--- initng/src/initng_process_db.c	(original)
+++ initng/src/initng_process_db.c	Wed Feb  8 07:26:15 2006
@@ -52,7 +52,7 @@
     /* null pid */
     new_p->pid = 0;
 
-    /* reset returncode */
+    /* reset return code */
     /* XXX: magic number - what does it mean? */
     new_p->r_code = -10;
 

Modified: initng/src/initng_service_cache.c
==============================================================================
--- initng/src/initng_service_cache.c	(original)
+++ initng/src/initng_service_cache.c	Wed Feb  8 07:26:15 2006
@@ -42,7 +42,7 @@
 
 /*
  * This is a simple list_add(&service->list), but
- * will first check for dupletts.
+ * will first check for duplicates.
  */
 int initng_service_cache_add(service_cache_h * s)
 {
@@ -90,13 +90,13 @@
     /* name has to diff */
     new_serv->name = name;
 
-    /* initziate the data structure */
+    /* initialize the data structure */
     INIT_LIST_HEAD(&(new_serv->data.list));
 
     /* copy over all strings */
     d_copy_all(&s->data.list, &new_serv->data.list);
 
-    /* we must clear pointers, otherwise this servise 
+    /* we must clear pointers, otherwise this service 
      * will not be added to list
      */
     new_serv->list.prev = new_serv->list.next = NULL;
@@ -106,7 +106,7 @@
 
 /*
  * Allocates an entry, in memory, and sets defaults,
- * name & type, initziate lits.
+ * name & type, initialize lists.
  */
 service_cache_h *initng_service_cache_new(const char *name, stype_h * type)
 {
@@ -124,7 +124,7 @@
     new_s->name = i_strdup(name);
     new_s->type = type;
 
-    /* initziate the data list struct */
+    /* initialize the data list struct */
     INIT_LIST_HEAD(&(new_s->data.list));
     return (new_s);
 }
@@ -179,7 +179,7 @@
     /* did not find any */
     return NULL;
 
-    /* no need in pattern mathcing, because of unique names in cache (TeLich) */
+    /* no need in pattern matching, because of unique names in cache (TheLich) */
 
     /* walk the active db and compere */
     current = NULL;
@@ -188,7 +188,7 @@
         assert(current->name);
         /*
          * then try to find alike name
-         * When searching for services, in service chace, the match is reverse,
+         * When searching for services, in service cache, the match is reverse,
          * then how active_db_find_by_name.
          * 
          * The service name searching data for is always correct, but the data,
@@ -219,7 +219,7 @@
     if ((current = initng_service_cache_find_by_name(service)))
         return (current);
 
-    /* Dont return any match, if the user was searching for an exact match */
+    /* Don't return any match, if the user was searching for an exact match */
     if (!strchr(service, '/'))
         return NULL;
 
@@ -333,7 +333,7 @@
 int initng_service_cache_find_father(service_cache_h * service)
 {
     assert(service);
-    /* if fahter is known, return ok */
+    /* if father is known, return ok */
     if (service->father)
         return (TRUE);
     /* if no father is needed */
@@ -376,7 +376,7 @@
     if ((tmp = d_get_string_var(type, vn, &s->data.list)))
         return (tmp);
 
-    /* look for data in my parrent */
+    /* look for data in my parent */
     if (initng_service_cache_find_father(s) && s->father)
         if ((tmp = initng_service_cache_get_string_var(type, vn, s->father)))
             return (tmp);
@@ -397,7 +397,7 @@
     /* try to find in local data */
     if (d_is_var(type, vn, &s->data.list))
         return (d_get_int_var(type, vn, &s->data.list));
-    /* look for data in my parrent */
+    /* look for data in my parent */
     if (initng_service_cache_find_father(s) && s->father)
         return (initng_service_cache_get_int_var(type, vn, s->father));
     return (0);
@@ -419,7 +419,7 @@
     /* try to find in local data */
     if ((tmp = d_get_next_string_var(type, vn, &s->data.list, last)))
         return (tmp);
-    /* look for data in my parrent */
+    /* look for data in my parent */
     if (initng_service_cache_find_father(s) && s->father)
         if ((tmp =
              initng_service_cache_get_next_string_var(type, vn, s->father,
@@ -439,7 +439,7 @@
     assert(s);
     if (d_is_var(type, vn, &s->data.list))
         return (TRUE);
-    /* look for data in my parrent */
+    /* look for data in my parent */
     if (initng_service_cache_find_father(s) && s->father)
         if (initng_service_cache_is_var(type, vn, s->father))
             return (TRUE);

Modified: initng/src/initng_service_cache.h
==============================================================================
--- initng/src/initng_service_cache.h	(original)
+++ initng/src/initng_service_cache.h	Wed Feb  8 07:26:15 2006
@@ -42,7 +42,7 @@
     struct list_head list;
 };
 
-/* service haneling functions */
+/* service handling functions */
 int initng_service_cache_add(service_cache_h * s);
 service_cache_h *initng_service_cache_copy(char *name, service_cache_h * s);
 service_cache_h *initng_service_cache_new(const char *name, stype_h * type);

Modified: initng/src/initng_service_data_types.c
==============================================================================
--- initng/src/initng_service_data_types.c	(original)
+++ initng/src/initng_service_data_types.c	Wed Feb  8 07:26:15 2006
@@ -1,5 +1,5 @@
 
-/* Initng, a next generatind sysvinit replacement.
+/* Initng, a next generation sysvinit replacement.
  * Copyright (C) 2005 Jimmy Wennlund <jimmy.wennlund at gmail.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -42,7 +42,7 @@
 
     /*
      * set the opt_name_len,
-     * an optimze so that we dont need to strlen every time accessing this one.
+     * an optimize so that we don't need to strlen every time accessing this one.
      */
     if (ent->opt_name)
         ent->opt_name_len = strlen(ent->opt_name);
@@ -84,7 +84,7 @@
 }
 
 /*
- * This safely deleates and option from option_db.
+ * This safely deletes and option from option_db.
  * safely removes all data on that option from active_db, and service_db
  * that depends on the option, removed.
  */
@@ -114,7 +114,7 @@
 
 /*
  * This walks the option_db and
- * removing ALL antrys.
+ * removing ALL entries.
  */
 void initng_service_data_types_free_all(void)
 {

Modified: initng/src/initng_service_data_types.h
==============================================================================
--- initng/src/initng_service_data_types.h	(original)
+++ initng/src/initng_service_data_types.h	Wed Feb  8 07:26:15 2006
@@ -42,14 +42,14 @@
 typedef struct ss_entry s_entry;
 struct ss_entry
 {
-    /* set in staticly */
+    /* set in statically */
     const char *opt_name;
     e_dt opt_type;
     stype_h *ot;
     const char *opt_desc;
     s_entry *alias;
 
-    /* this shud not be set static */
+    /* this should not be set static */
     int opt_name_len;
     struct list_head list;
 };

Modified: initng/src/initng_service_types.h
==============================================================================
--- initng/src/initng_service_types.h	(original)
+++ initng/src/initng_service_types.h	Wed Feb  8 07:26:15 2006
@@ -27,7 +27,7 @@
 /* service types struct */
 typedef struct
 {
-    /* Name of servicetype */
+    /* Name of service type */
     const char *name;
 
     /* Called to start service */
@@ -39,7 +39,7 @@
     /* Called to restart service */
     int (*restart_service) (active_db_h * service);
 
-    /* leng of name_len */
+    /* length of name_len */
     int name_len;
 
     /* list of stypes */

Modified: initng/src/initng_signal.c
==============================================================================
--- initng/src/initng_signal.c	(original)
+++ initng/src/initng_signal.c	Wed Feb  8 07:26:15 2006
@@ -41,8 +41,8 @@
 static void sighup(int sig);
 
 /*
- * These are gloval variables, that got set,
- * by the signals rescived.
+ * These are global variables, that got set,
+ * by the signals received.
  */
 volatile int initng_signal_got_keyboard_request = FALSE;
 volatile int initng_signal_got_ctrl_alt_del = FALSE;
@@ -51,7 +51,7 @@
 volatile int initng_signal_got_sighup = FALSE;
 
 /*
- * If we got an chiled that died, this haldler is called.
+ * If we got an child that died, this handler is called.
  */
 void initng_signal_handle_sigchild(void)
 {
@@ -167,7 +167,7 @@
 }
 
 /*
- * This is called in main() initziation, and will enable signals when it happends.
+ * This is called in main() initialization, and will enable signals when it happens.
  */
 void initng_signal_enable(void)
 {
@@ -176,9 +176,9 @@
     /* clear interrupt cache */
     /* TODO FIGUREITOUT - Catch signals */
     /*  signal(SIGPWR,sighandler); don't know what to do about it */
-    /*  signal(SIGHUP,sighandler); signal for plugins to do something */
+    /*  signal(SIGHUP,sighandler); signal for plug-ins to do something */
     /*  (recreate control file for example) */
-    /* SA_NOCLDSTOP -->  Get notification when childs stops living */
+    /* SA_NOCLDSTOP -->  Get notification when child stops living */
     /* SA_RESTART --> make certain system calls restartable across signals */
     /*   Normally if a program is in a system call and a signal is */
     /*   delivered, the system call exits with and error sets errno */
@@ -224,7 +224,7 @@
 
 /* 
  * Disable signals, called when initng are exiting.
- * somethimes, we don't want to be disturbed with signals.
+ * sometimes, we don't want to be disturbed with signals.
  */
 void initng_signal_disable(void)
 {

Modified: initng/src/initng_static_data_id.c
==============================================================================
--- initng/src/initng_static_data_id.c	(original)
+++ initng/src/initng_static_data_id.c	Wed Feb  8 07:26:15 2006
@@ -38,7 +38,7 @@
 };
 s_entry REQUIRE = { "require", STRINGS, NULL, "Need to be up, fail if not found." };
 s_entry FROM_FILE = { "from_file", STRING, NULL, NULL };
-s_entry ENV = { "env", VARIABLE_STRING, NULL, "Sets an enviromental variable."
+s_entry ENV = { "env", VARIABLE_STRING, NULL, "Sets an environmental variable."
 };
 s_entry RESTARTING = { NULL, SET, NULL, NULL };
 s_entry UP_ON_FAILURE = { "up_on_failure", SET, NULL,
@@ -51,7 +51,7 @@
 /*
  * add some default options, that is needed by core, and should
  * be in option_db by default.
- * This function is called, from main(), initziation.
+ * This function is called, from main(), initialization.
  */
 void initng_static_data_id_add_defaults(void)
 {

Modified: initng/src/initng_static_process_types.c
==============================================================================
--- initng/src/initng_static_process_types.c	(original)
+++ initng/src/initng_static_process_types.c	Wed Feb  8 07:26:15 2006
@@ -63,7 +63,7 @@
     D_("(%s): initial status: \"%s\".\n",
        service->name, service->current_state->state_name);
 
-    /* Set the universal variable, that signalize that something happend */
+    /* Set the universal variable, that signalize that something happened */
     initng_global_set_interrupt();
 
     /*

Modified: initng/src/initng_static_service_types.c
==============================================================================
--- initng/src/initng_static_service_types.c	(original)
+++ initng/src/initng_static_service_types.c	Wed Feb  8 07:26:15 2006
@@ -100,11 +100,11 @@
         if (current == service_to_stop)
             continue;
 
-        /* dont autostop runlevels or virtuals */
+        /* don't auto stop runlevels or virtuals */
         if (current->type == &TYPE_VIRTUAL)
             continue;
 
-        /* dont stop a stopping service */
+        /* don't stop a stopping service */
         if (current->current_state == &STOPPING)
             continue;
 

Modified: initng/src/initng_static_states.c
==============================================================================
--- initng/src/initng_string_tools.c	(original)
+++ initng/src/initng_string_tools.c	Wed Feb  8 07:26:15 2006
@@ -35,11 +35,11 @@
  * this splits an long string, with separators, like \n , ; ' '
  * into an char **
  * buf: the line to split.
- * len; An pointer sent back with lenght
- * plus: Allocate this mutch extra char ** size;
+ * len; An pointer sent back with length
+ * plus: Allocate this much extra char ** size;
  * ofs: (offset) start a bit into the buf
  *
- * OBS, this functions only creats a pointer list, that links
+ * OBS, this functions only creates a pointer list, that links
  * to buf, if buf is freed, the list dies!
  */
 char **split_n(char *buf, int *len, int plus, int ofs)
@@ -79,9 +79,9 @@
 }
 
 
-/** Relinks a string to a argv-like string-array.
- * Example: \t  /bin/executeable --ham -flt   --moohoho  lalala
- *       => \t  /bin/executeable\0--ham\0-flt\0  --moo\0hoho\0 lalala
+/** Re-links a string to a argv-like string-array.
+ * Example: \t  /bin/executable --ham -flt   --moohoho  lalala
+ *       => \t  /bin/executable\0--ham\0-flt\0  --moo\0hoho\0 lalala
  *    argv:     ^[0]              ^[1]   ^[2]    ^[3]   ^[4]   ^[5]
  *    argc: 6
  *
@@ -129,9 +129,9 @@
 
 
 /*
- * a simple strncasecmp, thats only returns TRUE or FALSE
+ * a simple strncasecmp, which only returns TRUE or FALSE
  * it will also add the pointer of string, the value, to forward the
- * pinter to next word.
+ * pointer to next word.
  */
 int st_cmp(char **string, const char *to_cmp)
 {
@@ -162,7 +162,7 @@
 /*
  * Senses what in the string, that is a word, (can be a
  * line with "this is one word", it will i_strdup it, and
- * add word lenght on string pointer
+ * add word length on string pointer
  */
 char *st_dup_next_word(char **string)
 {
@@ -320,7 +320,7 @@
     while ((*string)[i] != '\0')
         i++;
 
-    /* rewind util standing on a '/' */
+    /* rewind until standing on a '/' */
     while (i && (*string)[i] != '/')
         i--;
 
@@ -336,7 +336,7 @@
 /*
  * This search for a pattern.
  * If string is "net/eth0" then pattern "net/et*" and pattern "net/eth?"
- * shoud return true.
+ * should return true.
  */
 int service_match(const char *string, const char *pattern)
 {

Modified: initng/src/initng_string_tools.h
==============================================================================
--- initng/src/initng_string_tools.h	(original)
+++ initng/src/initng_string_tools.h	Wed Feb  8 07:26:15 2006
@@ -46,7 +46,7 @@
     if((s)[0]!='\0') (s)++;
 
 /*
- * REALLY_JUMPT_TO_NEXT_ROW wont stop on a ';' char.
+ * REALLY_JUMP_TO_NEXT_ROW wont stop on a ';' char.
  */
 #define REALLY_JUMP_TO_NEXT_ROW(s) \
     while((s)[0] != '\0' && (s)[0] != '\n') \

Modified: initng/src/initng_struct_data.c
==============================================================================
--- initng/src/initng_struct_data.c	(original)
+++ initng/src/initng_struct_data.c	Wed Feb  8 07:26:15 2006
@@ -49,7 +49,7 @@
     while (type->opt_type == ALIAS && type->alias) \
         type = type->alias;
 
-/* check if vn exitsts, that its correct */
+/* check if vn exists, that its correct */
 #define VN_MATCH(vnc, vnt) \
     (!vnc || (vnt && strcasecmp(vnc, vnt)==0))
 
@@ -66,7 +66,7 @@
 
     ALIAS_WALK;
 
-    /* walk thru all entrys, on adress */
+    /* walk through all entries, on address */
     list_for_each_entry_prev(current, address, list)
     {
         /* make sure there is really a new entry */
@@ -104,7 +104,7 @@
         return (NULL);
     }
 
-    /* walk thru all entrys, on adress */
+    /* walk through all entries, on address */
     list_for_each_entry(current, address, list)
     {
         /* if this type is right, return string */
@@ -144,7 +144,7 @@
         return (0);
     }
 
-    /* walk thru all entrys on adress */
+    /* walk through all entries on address */
     list_for_each_entry(current, d, list)
     {
         /* if this type is right, return int */
@@ -183,7 +183,7 @@
         return (NULL);
     }
 
-    /* walk thru all in d, will be but into current */
+    /* walk through all in d, will be but into current */
     list_for_each_entry_prev(current, d, list)
     {
         /* if the returned type is not that type we are looking for, continue */
@@ -362,7 +362,7 @@
     s_data *current = NULL;
     int count = 0;
 
-    /* walk thru all entrys on adress */
+    /* walk through all entries on address */
     list_for_each_entry(current, d, list)
     {
         if (!type || current->type == type)
@@ -393,7 +393,7 @@
         return (FALSE);
     }
 
-    /* walk thru all entrys on adress */
+    /* walk through all entries on address */
     list_for_each_entry(current, d, list)
     {
         if (current->type == type && VN_MATCH(current->vn, vn))
@@ -432,7 +432,7 @@
         return;
     }
 
-    /* check if its set alredy */
+    /* check if its set already */
     if (IT(SET))
         if (d_is_var(type, vn, d))
             return;
@@ -493,7 +493,7 @@
 
     ALIAS_WALK;
 
-    /* walk thru all entrys on adress */
+    /* walk through all entries on address */
     list_for_each_entry_safe(current, s, d, list)
     {
         /* if this is not the type, continue */
@@ -511,7 +511,7 @@
             continue;
         }
 
-        /* or if cariable name matches */
+        /* or if variable name matches */
         if (VN_MATCH(current->vn, vn))
         {
             F_("vn matches, freeing\n");
@@ -530,7 +530,7 @@
 
     assert(d);
 
-    /* walk thru all entrys on adress */
+    /* walk through all entries on address */
     list_for_each_entry_safe(current, s, d, list)
     {
         /* walk, and remove all */

Modified: initng/src/main.c
==============================================================================
--- initng/src/main.c	(original)
+++ initng/src/main.c	Wed Feb  8 07:26:15 2006
@@ -363,27 +363,27 @@
 
     if(getuid()!=0)
     {
-	W_("Initng is designed to run as root user, a lot of functionallity will not work correctly.\n");
+	W_("Initng is designed to run as root user, a lot of functionality will not work correctly.\n");
     }
 
     /* if this is real init */
     if (g.i_am_init)
     {
-        /* when last service stoped, offer a sulogin */
+        /* when last service stopped, offer a sulogin */
         g.when_out = THEN_SULOGIN;
         if (!g.runlevel)
             initng_main_set_runlevel("default");
 
         if (!g.hot_reload)
         {
-            /* static function abowe, initziates the system */
+            /* static function above, initialize the system */
             setup_console();
         }
 
     }
     else
     {
-        /* when last service stoped, quit initng */
+        /* when last service stopped, quit initng */
         g.when_out = THEN_QUIT;
         initng_main_set_runlevel("fake-default");
     }
@@ -438,10 +438,10 @@
     {
         D_("MAIN_LOOP: %i\n", loop_counter++);
 
-        /* Update current time, save this in global so we dont need to call time() that often. */
+        /* Update current time, save this in global so we don't need to call time() that often. */
         gettimeofday(&g.now, NULL);
 
-        /* if this isnt a normal timeout loop */
+        /* if this isn't a normal timeout loop */
         if (g.sleep_seconds != TIMEOUT)
         {
             initng_global_set_interrupt();
@@ -451,8 +451,8 @@
 
 
         /*
-         * If it has gone more then 1h sence last
-         * main loop, or if clock has gon backwards,
+         * If it has gone more then 1h since last
+         * main loop, or if clock has gone backwards,
          * reset it.
          */
         if ((g.now.tv_sec - last.tv_sec) >= 3600
@@ -471,7 +471,7 @@
         /* Check for sigchld */
         if (initng_signal_got_sigchld)
         {
-            D_("There are dead childs to handle!\n");
+            D_("There are dead children to handle!\n");
             initng_signal_got_sigchld = FALSE;
             initng_signal_handle_sigchild();
         }
@@ -483,7 +483,7 @@
             initng_signal_got_alarm = FALSE;
             /* Check for timed out stopping services for SIGKILL */
             initng_handler_term_stopping_services();
-            /* Check timers plugins */
+            /* Check timers plug-ins */
             initng_plugin_callers_alarm();
         }
 
@@ -492,7 +492,7 @@
         {
             D_("Got sighup, checking sighup plugin ...\n");
             initng_signal_got_sighup = FALSE;
-            /* Check timers plugins */
+            /* Check timers plug-ins */
             initng_plugin_callers_hup();
         }
 
@@ -524,10 +524,10 @@
 
         /* 
          * When g.interrupt is set, we are going to launch all handlers,
-         * for all services, its in here there is acutally happen
+         * for all services, its in here there is actually happen
          * something.
          *
-         * It is a while loop, becouse it will probably reset g.interrupt
+         * It is a while loop, because it will probably reset g.interrupt
          * many times, so this would be like a mini main-loop.
          */
         while (g.interrupt == TRUE)
@@ -547,7 +547,7 @@
         }
 
 
-        /* if interupt is set, dont waits cpu on more checks */
+        /* if interrupt is set, don't waits CPU on more checks */
         if (g.interrupt == TRUE)
             continue;
 
@@ -557,7 +557,7 @@
          */
 
         /*
-         * call the main_hooks in all plugins.
+         * call the main_hooks in all plug-ins.
          * OBS! This part in mainloop is expensive.
          */
         {
@@ -571,7 +571,7 @@
 
 
         /*
-         * Check if there are any running processes left, otherwise quit, when_out try to do something when this happends.
+         * Check if there are any running processes left, otherwise quit, when_out try to do something when this happens.
          *
          * This check is also expensive.
          */
@@ -584,7 +584,7 @@
             continue;
         }
 
-        /* if interupt is set, dont waits cpu on a poll */
+        /* if interrupt is set, don't waits CPU on a poll */
         if (g.interrupt == TRUE)
             continue;
 


More information about the Initng-svn mailing list
--- initng/src/initng_fd.c	(original)
+++ initng/src/initng_fd.c	Wed Feb  8 07:26:15 2006
@@ -56,7 +56,7 @@
 
 /*
  * This function delivers what read to plugin,
- * thrue the hooks.
+ * through the hooks.
  * If no hook is found, or no return TRUE, it will
  * be printed to screen anyway.
  */
@@ -82,7 +82,7 @@
 #endif
     }
 
-    /* make sure someone handleded this */
+    /* make sure someone handled this */
     if (delivered != TRUE)
         fprintf(stdout, "%s", &process->buffer[process->buffer_pos]);
 }
@@ -94,7 +94,7 @@
 static int initng_fd_process_readpipe_read(active_db_h * service,
                                            process_h * p, int flush_buffer)
 {
-    int len = 0;                /* lenght of data read */
+    int len = 0;                /* length of data read */
 
     S_;
 
@@ -127,7 +127,7 @@
 
     /* if we got something. */
 
-    /* null the end to make sure we dont get an overflow */
+    /* null the end to make sure we don't get an overflow */
     p->buffer[p->buffer_pos + len] = '\0';
 
     /* if max buffer is reached, make sure it flushes it */
@@ -137,13 +137,13 @@
     /* let all plugin take part of data */
     initng_fd_plugin_readpipe(service, p);
 
-    /* increase the buffer possision */
+    /* increase the buffer position */
     if (flush_buffer)
         p->buffer_pos = 0;
     else
         p->buffer_pos = p->buffer_pos + len;
 
-    /* return lenght of data read */
+    /* return length of data read */
     return (len);
 }
 
@@ -160,7 +160,7 @@
 
     /*
      * flush_buffer is set, and readpipe is called just
-     * before process are beeing freed, when the pocess
+     * before process are being freed, when the process
      * is dead.
      */
     if (flush_buffer)
@@ -171,7 +171,7 @@
         fcntl(p->out_pipe[0], F_SETFL, fd_flags | O_NONBLOCK);
     }
 
-    /* get data from process, it return lenght of data got */
+    /* get data from process, it return length of data got */
     len = initng_fd_process_readpipe_read(service, p, flush_buffer);
 
     if (!flush_buffer)
@@ -211,15 +211,15 @@
 /*
  * FILEDESCRIPTORPOLLNG
  *
  * Filedescriptors are scaned in 3 steps.
  * First, scan all plugins, and processes after filedescriptors to
  * watch, and add them with FD_SET(); added++;
  *
  * Second, Run select if there where any added, with an timeout set
  * when function was called.
  *
  * Third, if select returns that there is data to fetch, walk over
  * plugins and filedescriptors again, and call plugins or initng_process_readpipe
  * with pointer to plugin/service.
  *
  * This function will return FALSE, if it timeout, or if there was
@@ -236,7 +236,7 @@
     s_call *currentC, *qC;
     process_h *currentP, *qP;
 
-    /* initziation */
+    /* initialization */
     S_;
     FD_ZERO(&readset);
 
@@ -250,7 +250,7 @@
      */
 
 
-    /* scan through active plugins that have listening file descriptors, and add them */
+    /* scan through active plug-ins that have listening file descriptors, and add them */
     currentC = NULL;
     while_list(currentC, &g.FDWATCHERS)
     {
@@ -288,21 +288,21 @@
     /* check if there are any set */
     if (added <= 0)
     {
-        D_("No filedescriptors set.\n");
+        D_("No file descriptors set.\n");
         sleep(timeout);
         return (TRUE);
     }
-    D_("%i filedescriptors added.\n", added);
+    D_("%i file descriptors added.\n", added);
 
 
     /* If interrupt then return and do main loop, it doesn't hurt if the filebuffers have a bit more data anyway */
     if (g.interrupt)
         return (TRUE);
 
     /* make the select */
     retval = select(256, &readset, NULL, NULL, &tv);
 
-    /* if interupt is set, don't continue handeling fussy fds */
+    /* if interrupt is set, don't continue handling fussy fds */
     if (g.interrupt)
         return (TRUE);
 
@@ -322,15 +322,15 @@
 
     D_("%d fd's active\n", retval);
 
     /* If a fsck is running select will always return one filehandler active, we give it 0.1 seconds to get some more data into the buffer. */
     sleep(0.1);
 
 
     /*
-     * STEP 3:  Find the plugins/processes that handles the fd input, and call them
+     * STEP 3:  Find the plug-ins/processes that handles the fd input, and call them
      */
 
-    /* Now scan throught callers */
+    /* Now scan through callers */
     currentC = NULL;
     qC = NULL;
     while_list_safe(currentC, &g.FDWATCHERS, qC)
@@ -342,9 +342,9 @@
         if (!FD_ISSET(currentC->c.fdh->fds, &readset))
             continue;
 
-        D_("Calling pluginhandler for fd #%i\n", currentC->c.fdh->fds);
+        D_("Calling plugin handler for fd #%i\n", currentC->c.fdh->fds);
         (*currentC->c.fdh->call_module) (currentC->c.fdh);
-        D_("pluginhandler for fd #%i returned!\n", currentC->c.fdh->fds);
+        D_("plugin handler for fd #%i returned!\n", currentC->c.fdh->fds);
 
         /* Found match, that means we need to look for one less, if we've found all we should then return */
         retval--;
@@ -211,15 +211,15 @@
  * FILEDESCRIPTORPOLLNG
  *
- * Filedescriptors are scaned in 3 steps.
- * First, scan all plugins, and processes after filedescriptors to
+ * File descriptors are scanned in 3 steps.
+ * First, scan all plug-ins, and processes after file descriptors to
  * watch, and add them with FD_SET(); added++;
  *
@@ -211,15 +211,15 @@
  *
  * Third, if select returns that there is data to fetch, walk over
- * plugins and filedescriptors again, and call plugins or initng_process_readpipe
+ * plug-ins and file descriptors again, and call plug-ins or initng_process_readpipe
  * with pointer to plugin/service.
  *
@@ -288,21 +288,21 @@
 
 
-    /* If interrupt then return and do main loop, it doesn't hurt if the filebuffers have a bit more data anyway */
+    /* If interrupt then return and do main loop, it doesn't hurt if the file buffers have a bit more data anyway */
     if (g.interrupt)
         return (TRUE);
@@ -322,15 +322,15 @@
     D_("%d fd's active\n", retval);
 
-    /* If a fsck is running select will always return one filehandler active, we give it 0.1 seconds to get some more data into the buffer. */
+    /* If a fsck is running select will always return one file handler active, we give it 0.1 seconds to get some more data into the buffer. */
     sleep(0.1);
 

Modified: initng/src/initng_fork.c
==============================================================================
--- initng/src/initng_handler.c	(original)
+++ initng/src/initng_handler.c	Wed Feb  8 07:26:15 2006
@@ -51,7 +51,7 @@
 
 
 /*
- * This funtion is run from main when g.interrupt is set.
+ * This function is run from main when g.interrupt is set.
  * Will do special actions, for some status mode.
  */
 void initng_handler_run_interrupt_handlers(void)
@@ -66,7 +66,7 @@
         assert(current->name);
         assert(current->current_state);
 
-        /* call statehandler, now when we got an g.interrupt */
+        /* call state handler, now when we got an g.interrupt */
         if (current->current_state->state_interrupt)
             (*current->current_state->state_interrupt) (current);
     }
@@ -139,7 +139,7 @@
         }
     }
 
-    /* reactivete the alarm if set */
+    /* reactivate the alarm if set */
     if (reactivate_alarm == TRUE)
         initng_global_set_sleep(timeout);
 }
@@ -169,7 +169,7 @@
         return (FALSE);
     }
 
     /* it might alredy be starting */
     if (!IS_MARK(service_to_start, &LOADING)
         && (IS_STARTING(service_to_start) || IS_WAITING(service_to_start)))
     {
@@ -177,7 +177,7 @@
         return (TRUE);
     }
 
     /* it might alredy be up */
     if (IS_UP(service_to_start))
     {
         D_("service %s is already up!\n", service_to_start->name);
@@ -231,7 +231,7 @@
     /* IF service is stopping, do nothing. */
     if (IS_STOPPING(service_to_stop))
     {
-        D_("service %s is stopping alldedy!\n", service_to_stop->name);
+        D_("service %s is stopping already!\n", service_to_stop->name);
         return (TRUE);
     }
 
@@ -271,7 +271,7 @@
     assert(service_to_restart->name);
     assert(service_to_restart->current_state);
     
-    /* type has to be nown to restart the service */
+    /* type has to be known to restart the service */
     if (!service_to_restart->type)
         return (FALSE);
 
@@ -311,7 +311,7 @@
 	}
 	
     }
-	/* else try creat and load a new service */
+	/* else try create and load a new service */
     else if (!(to_load = initng_common_load_to_active(service)))
     {
 
@@ -336,7 +336,7 @@
 
     while_active_db_safe(ser, q)
     {
-        /* dont stop a stopping service */
+        /* don't stop a stopping service */
         if (IS_STOPPING(ser))
             continue;
 
@@ -169,7 +169,7 @@
     }
 
-    /* it might alredy be starting */
+    /* it might already be starting */
     if (!IS_MARK(service_to_start, &LOADING)
         && (IS_STARTING(service_to_start) || IS_WAITING(service_to_start)))
@@ -177,7 +177,7 @@
     }
 
-    /* it might alredy be up */
+    /* it might already be up */
     if (IS_UP(service_to_start))
     {

Modified: initng/src/initng_kill_handler.c
==============================================================================
--- initng/src/initng_static_states.c	(original)
+++ initng/src/initng_static_states.c	Wed Feb  8 07:26:15 2006
@@ -146,7 +146,7 @@
         if (initng_depend(service_to_start, current) == FALSE)
             continue;
 
-        /* if servuce dep on is starting, wait a bit */
+        /* if service dep on is starting, wait a bit */
         if (IS_STARTING(current))
             return;
 
@@ -161,10 +161,10 @@
         }
     }
 
     /* check with start dep med dependencys */
     if(initng_depend_start_dep_met(service_to_start)!=TRUE)
     {
-	D_("Some plugin say that the start dependencys for this service is not met.\n");
+	D_("Some plugin say that the start dependencies for this service is not met.\n");
 	return;
     }
 
@@ -263,7 +263,7 @@
         if (initng_depend(current, service_to_stop) == FALSE)
             continue;
 
-        /* if its done, this is pefrect */
+        /* if its done, this is perfect */
         if (IS_DOWN(current))
             continue;
 
@@ -284,10 +284,10 @@
         return;
     }
     
     /* check with stop dep med dependencys */
     if(initng_depend_stop_dep_met(service_to_stop)!=TRUE)
     {
-	D_("Some plugin say that the start dependencys for this service is not met.\n");
+	D_("Some plugin say that the start dependencies for this service is not met.\n");
 	return;
     }
 
@@ -387,7 +387,7 @@
     }
 
     initng_common_mark_service(service_to_stop, &FAIL_STOPPING);
-    F_("DONT KNOW HOW TO STOP %s!\n", service_to_stop->name);
+    F_("DON'T KNOW HOW TO STOP %s!\n", service_to_stop->name);
 }
 
 static void kill_daemon(active_db_h * service_to_stop)
@@ -444,7 +444,7 @@
            process->pid, service_to_stop->name);
     }
 
-    /* Uhm, this doesnt work : kill(-service_to_stop->start_process->pid, SIGTERM); */
+    /* Uhm, this doesn't work : kill(-service_to_stop->start_process->pid, SIGTERM); */
     kill(process->pid, SIGTERM);
 
     if (initng_active_db_is(&STOP_TIMEOUT, service_to_stop))
@@ -474,7 +474,7 @@
         if (current == service_stopped)
             continue;
 
         /* DONT stop runlevels OR virtuals */
         if (current->type == &TYPE_VIRTUAL)
             continue;
 
@@ -482,7 +482,7 @@
         if (initng_depend(current, service_stopped) == FALSE)
             continue;
 
         /* dont stop a stopped service */
         if (IS_DOWN(current))
             continue;
 
@@ -161,10 +161,10 @@
     }
 
-    /* check with start dep med dependencys */
+    /* check with start dep med dependencies */
     if(initng_depend_start_dep_met(service_to_start)!=TRUE)
     {
@@ -284,10 +284,10 @@
     }
     
-    /* check with stop dep med dependencys */
+    /* check with stop dep med dependencies */
     if(initng_depend_stop_dep_met(service_to_stop)!=TRUE)
     {
@@ -474,7 +474,7 @@
             continue;
 
-        /* DONT stop runlevels OR virtuals */
+        /* DON'T stop runlevels OR virtuals */
         if (current->type == &TYPE_VIRTUAL)
             continue;
@@ -482,7 +482,7 @@
             continue;
 
-        /* dont stop a stopped service */
+        /* don't stop a stopped service */
         if (IS_DOWN(current))
             continue;

Modified: initng/src/initng_string_tools.c
==============================================================================